@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '1.302013_003';
+our $VERSION = '1.302013_004';
 $VERSION = eval $VERSION;    ## no critic (BuiltinFunctions::ProhibitStringyEval)
 
 BEGIN {
@@ -622,7 +622,7 @@ sub _ok_debug {
     my $self = shift;
     my ($trace, $orig_name, $is_todo) = @_;
     my $msg = $is_todo ? "Failed (TODO)" : "Failed";
-    $self->diag("\n") if $ENV{HARNESS_ACTIVE};
+    print {$self->_diag_fh} "\n" if $ENV{HARNESS_ACTIVE};
 
     my (undef, $file, $line) = $trace->call;
     if (defined $orig_name) {
@@ -634,6 +634,12 @@ sub _ok_debug {
     }
 }
 
+sub _diag_fh {
+    my $self = shift;
+    local $Level = $Level + 1;
+    return $self->in_todo ? $self->todo_output : $self->failure_output;
+}
+
 sub _unoverload {
     my ($self, $type, $thing) = @_;
 
@@ -1120,6 +1126,7 @@ sub no_ending {
 
 sub diag {
     my $self = shift;
+    return unless @_;
 
     my $ctx = $self->ctx;
     $ctx->diag(join '' => map {defined($_) ? $_ : 'undef'} @_);
@@ -1129,6 +1136,7 @@ sub diag {
 
 sub note {
     my $self = shift;
+    return unless @_;
 
     my $ctx = $self->ctx;
     $ctx->note(join '' => map {defined($_) ? $_ : 'undef'} @_);
